@@ -11,7 +11,9 @@ import mbedtls.hash as hash
 import mbedtls.hmac as hmac
 import mbedtls.hkdf as hkdf
 import mbedtls.pk as pk
+import mbedtls.secrets as secrets
 import mbedtls.tls as tls
+import mbedtls.version as version
 import mbedtls.x509 as x509
 
 
@@ -22,7 +24,11 @@ __all__ = (
     "hkdf",
     "hmac",
     "pk",
+    "secrets",
     "tls",
     "version",
     "x509",
 )
+
+
+has_feature = version.has_feature
